
[![Build Status](https://travis-ci.com/TralahM/greydot-api.svg?branch=master)](https://travis-ci.com/TralahM/greydot-api)
[![License: MIT](https://img.shields.io/badge/License-MIT-red.svg)](https://opensource.org/licenses/MIT)
[![Organization](https://img.shields.io/badge/Org-TralahTek-blue.svg)](https://github.com/TralahTek)
[![HitCount](http://hits.dwyl.io/TralahM/greydot-api.svg)](http://dwyl.io/TralahM/greydot-api)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](https://github.com/TralahM/pull/)
[![GitHub pull-requests](https://img.shields.io/github/issues-pr/Naereen/StrapDown.js.svg)](https://gitHub.com/TralahM/greydot-api/pull/)
[![GitHub version](https://badge.fury.io/gh/Naereen%2FStrapDown.js.svg)](https://github.com/TralahM/greydot-api).
[![Made With](https://img.shields.io/badge/Language-Python-yellow.svg)](https://github.com/TralahM)

# greydot-api.


[![TralahM](https://img.shields.io/badge/Engineer-TralahM-blue.svg?style=for-the-badge)](https://github.com/TralahM)
[![TralahM](https://img.shields.io/badge/Maintainer-TralahM-green.svg?style=for-the-badge)](https://github.com/TralahM)

# Documentation

# How to Install
```console
$ pip install greydot-api
```

## Building from Source for Developers

```Bash
git clone https://github.com/TralahM/greydot-api.git
cd greydot-api
```

# Contributing
[See the Contributing File](CONTRIBUTING.rst)


[See the Pull Request File](PULL_REQUEST_TEMPLATE.md)


# Support

# LICENCE

[Read the license here](LICENSE)


# Acknowledgements

[Find me on Twitter](https://twitter.com/TralahM)

[Find me on Kaggle](https://kaggle.com/TralahM)


